rename blackcherry -> tweetbook; package demos as zips; rename intro -> adm101
diff --git a/asterix-doc/pom.xml b/asterix-doc/pom.xml
index ac03d02..039110a 100644
--- a/asterix-doc/pom.xml
+++ b/asterix-doc/pom.xml
@@ -54,6 +54,13 @@
<include>asterix-sdk-stable.js</include>
</includes>
</resource>
+ <resource>
+ <directory>../asterix-examples/target/</directory>
+ <includes>
+ <include>adm101-demo.zip</include>
+ <include>tweetbook-demo.zip</include>
+ </includes>
+ </resource>
</resources>
</configuration>
</execution>
diff --git a/asterix-examples/pom.xml b/asterix-examples/pom.xml
index 1268908..86d1978 100644
--- a/asterix-examples/pom.xml
+++ b/asterix-examples/pom.xml
@@ -16,4 +16,40 @@
<version>0.8.4-SNAPSHOT</version>
</parent>
<artifactId>asterix-examples</artifactId>
+
+ <build>
+ <plugins>
+ <plugin>
+ <artifactId>maven-assembly-plugin</artifactId>
+ <version>2.2-beta-5</version>
+ <executions>
+ <execution>
+ <id>adm101-demo-binary-assembly</id>
+ <configuration>
+ <appendAssemblyId>false</appendAssemblyId>
+ <finalName>adm101-demo</finalName>
+ <descriptor>src/main/assembly/adm101-demo-binary-assembly.xml</descriptor>
+ </configuration>
+ <phase>package</phase>
+ <goals>
+ <goal>single</goal>
+ </goals>
+ </execution>
+ <execution>
+ <id>tweetbook-demo-binary-assembly</id>
+ <configuration>
+ <appendAssemblyId>false</appendAssemblyId>
+ <finalName>tweetbook-demo</finalName>
+ <descriptor>src/main/assembly/tweetbook-demo-binary-assembly.xml</descriptor>
+ </configuration>
+ <phase>package</phase>
+ <goals>
+ <goal>single</goal>
+ </goals>
+ </execution>
+ </executions>
+ </plugin>
+ </plugins>
+ </build>
+ <packaging>pom</packaging>
</project>
diff --git a/asterix-examples/src/main/assembly/adm101-demo-binary-assembly.xml b/asterix-examples/src/main/assembly/adm101-demo-binary-assembly.xml
new file mode 100644
index 0000000..f9921a7
--- /dev/null
+++ b/asterix-examples/src/main/assembly/adm101-demo-binary-assembly.xml
@@ -0,0 +1,27 @@
+<!--
+ ! Copyright 2009-2013 by The Regents of the University of California
+ ! Licensed under the Apache License, Version 2.0 (the "License");
+ ! you may not use this file except in compliance with the License.
+ ! you may obtain a copy of the License from
+ !
+ ! http://www.apache.org/licenses/LICENSE-2.0
+ !
+ ! Unless required by applicable law or agreed to in writing, software
+ ! distributed under the License is distributed on an "AS IS" BASIS,
+ ! WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ ! See the License for the specific language governing permissions and
+ ! limitations under the License.
+ !-->
+<assembly>
+ <id>adm101-demo-binary-assembly</id>
+ <formats>
+ <format>zip</format>
+ </formats>
+ <includeBaseDirectory>false</includeBaseDirectory>
+ <fileSets>
+ <fileSet>
+ <directory>src/main/resources/adm101-demo</directory>
+ <fileMode>0755</fileMode>
+ </fileSet>
+ </fileSets>
+ </assembly>
diff --git a/asterix-examples/src/main/assembly/tweetbook-demo-binary-assembly.xml b/asterix-examples/src/main/assembly/tweetbook-demo-binary-assembly.xml
new file mode 100644
index 0000000..c9290cb
--- /dev/null
+++ b/asterix-examples/src/main/assembly/tweetbook-demo-binary-assembly.xml
@@ -0,0 +1,27 @@
+<!--
+ ! Copyright 2009-2013 by The Regents of the University of California
+ ! Licensed under the Apache License, Version 2.0 (the "License");
+ ! you may not use this file except in compliance with the License.
+ ! you may obtain a copy of the License from
+ !
+ ! http://www.apache.org/licenses/LICENSE-2.0
+ !
+ ! Unless required by applicable law or agreed to in writing, software
+ ! distributed under the License is distributed on an "AS IS" BASIS,
+ ! WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ ! See the License for the specific language governing permissions and
+ ! limitations under the License.
+ !-->
+<assembly>
+ <id>tweetbook-demo-binary-assembly</id>
+ <formats>
+ <format>zip</format>
+ </formats>
+ <includeBaseDirectory>false</includeBaseDirectory>
+ <fileSets>
+ <fileSet>
+ <directory>src/main/resources/tweetbook-demo</directory>
+ <fileMode>0755</fileMode>
+ </fileSet>
+ </fileSets>
+ </assembly>
diff --git a/asterix-examples/src/main/resources/intro/README.md b/asterix-examples/src/main/resources/adm101-demo/README.md
similarity index 100%
rename from asterix-examples/src/main/resources/intro/README.md
rename to asterix-examples/src/main/resources/adm101-demo/README.md
diff --git a/asterix-examples/src/main/resources/intro/admaql101.py b/asterix-examples/src/main/resources/adm101-demo/admaql101.py
similarity index 100%
rename from asterix-examples/src/main/resources/intro/admaql101.py
rename to asterix-examples/src/main/resources/adm101-demo/admaql101.py
diff --git a/asterix-examples/src/main/resources/intro/bottle.py b/asterix-examples/src/main/resources/adm101-demo/bottle.py
similarity index 100%
rename from asterix-examples/src/main/resources/intro/bottle.py
rename to asterix-examples/src/main/resources/adm101-demo/bottle.py
diff --git a/asterix-examples/src/main/resources/intro/demo.tpl b/asterix-examples/src/main/resources/adm101-demo/demo.tpl
similarity index 100%
rename from asterix-examples/src/main/resources/intro/demo.tpl
rename to asterix-examples/src/main/resources/adm101-demo/demo.tpl
diff --git a/asterix-examples/src/main/resources/intro/run_101_demo.py b/asterix-examples/src/main/resources/adm101-demo/run_101_demo.py
similarity index 100%
rename from asterix-examples/src/main/resources/intro/run_101_demo.py
rename to asterix-examples/src/main/resources/adm101-demo/run_101_demo.py
diff --git a/asterix-examples/src/main/resources/intro/static/css/bootstrap.min.css b/asterix-examples/src/main/resources/adm101-demo/static/css/bootstrap.min.css
similarity index 100%
rename from asterix-examples/src/main/resources/intro/static/css/bootstrap.min.css
rename to asterix-examples/src/main/resources/adm101-demo/static/css/bootstrap.min.css
diff --git a/asterix-examples/src/main/resources/intro/static/js/asterix-sdk-stable.js b/asterix-examples/src/main/resources/adm101-demo/static/js/asterix-sdk-stable.js
similarity index 100%
rename from asterix-examples/src/main/resources/intro/static/js/asterix-sdk-stable.js
rename to asterix-examples/src/main/resources/adm101-demo/static/js/asterix-sdk-stable.js
diff --git a/asterix-examples/src/main/resources/intro/static/js/bootstrap.min.js b/asterix-examples/src/main/resources/adm101-demo/static/js/bootstrap.min.js
similarity index 100%
rename from asterix-examples/src/main/resources/intro/static/js/bootstrap.min.js
rename to asterix-examples/src/main/resources/adm101-demo/static/js/bootstrap.min.js
diff --git a/asterix-examples/src/main/resources/intro/static/js/demo.js b/asterix-examples/src/main/resources/adm101-demo/static/js/demo.js
similarity index 100%
rename from asterix-examples/src/main/resources/intro/static/js/demo.js
rename to asterix-examples/src/main/resources/adm101-demo/static/js/demo.js
diff --git a/asterix-examples/src/main/resources/intro/static/js/jquery.min.js b/asterix-examples/src/main/resources/adm101-demo/static/js/jquery.min.js
similarity index 100%
rename from asterix-examples/src/main/resources/intro/static/js/jquery.min.js
rename to asterix-examples/src/main/resources/adm101-demo/static/js/jquery.min.js
diff --git a/asterix-examples/src/main/resources/intro/tinysocial/fbm.adm b/asterix-examples/src/main/resources/adm101-demo/tinysocial/fbm.adm
similarity index 100%
rename from asterix-examples/src/main/resources/intro/tinysocial/fbm.adm
rename to asterix-examples/src/main/resources/adm101-demo/tinysocial/fbm.adm
diff --git a/asterix-examples/src/main/resources/intro/tinysocial/fbu.adm b/asterix-examples/src/main/resources/adm101-demo/tinysocial/fbu.adm
similarity index 100%
rename from asterix-examples/src/main/resources/intro/tinysocial/fbu.adm
rename to asterix-examples/src/main/resources/adm101-demo/tinysocial/fbu.adm
diff --git a/asterix-examples/src/main/resources/intro/tinysocial/query.txt b/asterix-examples/src/main/resources/adm101-demo/tinysocial/query.txt
similarity index 100%
rename from asterix-examples/src/main/resources/intro/tinysocial/query.txt
rename to asterix-examples/src/main/resources/adm101-demo/tinysocial/query.txt
diff --git a/asterix-examples/src/main/resources/intro/tinysocial/twm.adm b/asterix-examples/src/main/resources/adm101-demo/tinysocial/twm.adm
similarity index 100%
rename from asterix-examples/src/main/resources/intro/tinysocial/twm.adm
rename to asterix-examples/src/main/resources/adm101-demo/tinysocial/twm.adm
diff --git a/asterix-examples/src/main/resources/intro/tinysocial/twu.adm b/asterix-examples/src/main/resources/adm101-demo/tinysocial/twu.adm
similarity index 100%
rename from asterix-examples/src/main/resources/intro/tinysocial/twu.adm
rename to asterix-examples/src/main/resources/adm101-demo/tinysocial/twu.adm
diff --git a/asterix-examples/src/main/resources/black-cherry/README.md b/asterix-examples/src/main/resources/black-cherry/README.md
deleted file mode 100755
index 84a8123..0000000
--- a/asterix-examples/src/main/resources/black-cherry/README.md
+++ /dev/null
@@ -1,19 +0,0 @@
-# Black Cherry Demo
-Author: Eugenia Gabrielova (genia.likes.science@gmail.com)
-
-## Dependencies
-
-A running, local AsterixDB instance (via Managix), of the latest master version.
-http://asterix.ics.uci.edu/documentation/install.html
-
-Please note that previous versions of this demo required Python's requests library.
-This dependency is no longer in place.
-
-## Steps
-
-0. Run your local AsterixDB instance via Managix.
-
-1. Go to the top level of this demo and run
-$ python run_black_cherry.py
-
-2. Enjoy http://localhost:8080/
diff --git a/asterix-examples/src/main/resources/tweetbook-demo/README.md b/asterix-examples/src/main/resources/tweetbook-demo/README.md
new file mode 100755
index 0000000..2b490e0
--- /dev/null
+++ b/asterix-examples/src/main/resources/tweetbook-demo/README.md
@@ -0,0 +1,14 @@
+# Tweetbook Demo
+Author: Eugenia Gabrielova (genia.likes.science@gmail.com)
+
+## Dependencies
+1. Python Requests library: [http://docs.python-requests.org/en/latest/user/install/](http://docs.python-requests.org/en/latest/user/install/)
+2. A local, running AsterixDB instance: [http://asterix.ics.uci.edu/documentation/install.html](http://asterix.ics.uci.edu/documentation/install.html)
+
+## Steps
+
+0. With your current working directory as the top level of this demo's hierarchy, execute:
+
+ $ python run_tweetbook_demo.py
+
+1. Visit http://localhost:8080/ in your browser.
diff --git a/asterix-examples/src/main/resources/black-cherry/bottle.py b/asterix-examples/src/main/resources/tweetbook-demo/bottle.py
similarity index 100%
rename from asterix-examples/src/main/resources/black-cherry/bottle.py
rename to asterix-examples/src/main/resources/tweetbook-demo/bottle.py
diff --git a/asterix-examples/src/main/resources/black-cherry/run_black_cherry.py b/asterix-examples/src/main/resources/tweetbook-demo/run_tweetbook_demo.py
similarity index 94%
rename from asterix-examples/src/main/resources/black-cherry/run_black_cherry.py
rename to asterix-examples/src/main/resources/tweetbook-demo/run_tweetbook_demo.py
index 7dbf84b..5307192 100755
--- a/asterix-examples/src/main/resources/black-cherry/run_black_cherry.py
+++ b/asterix-examples/src/main/resources/tweetbook-demo/run_tweetbook_demo.py
@@ -1,4 +1,4 @@
-import black_cherry_bootstrap
+import tweetbook_bootstrap
from urllib2 import URLError, urlopen
from urllib import urlencode
from json import loads, dumps
@@ -7,7 +7,7 @@
# Core Routing
@route('/')
def jsontest():
- return template('cherry')
+ return template('tweetbook')
@route('/static/<filename:path>')
def send_static(filename):
@@ -69,5 +69,5 @@
def run_asterix_update():
return (build_response("update", dict(request.query)))
-res = black_cherry_bootstrap.bootstrap()
+res = tweetbook_bootstrap.bootstrap()
run(host='localhost', port=8080, debug=True)
diff --git a/asterix-examples/src/main/resources/black-cherry/cherry.tpl b/asterix-examples/src/main/resources/tweetbook-demo/tweetbook.tpl
similarity index 92%
rename from asterix-examples/src/main/resources/black-cherry/cherry.tpl
rename to asterix-examples/src/main/resources/tweetbook-demo/tweetbook.tpl
index c5caccb..d6fb3b8 100755
--- a/asterix-examples/src/main/resources/black-cherry/cherry.tpl
+++ b/asterix-examples/src/main/resources/tweetbook-demo/tweetbook.tpl
@@ -18,7 +18,7 @@
<script src="static/js/bootstrap.min.js"></script>
<script src="static/js/asterix-sdk-stable.js"></script>
<script src="static/js/rainbowvis.js"></script>
- <script src="static/js/cherry.js"></script>
+ <script src="static/js/tweetbook.js"></script>
<style type="text/css">
@@ -81,9 +81,9 @@
<div class="container">
<!-- Welcome Message -->
<div class="row">
- <p>Welcome to the top-level page of the mysteriously named Black Cherry Demo of AsterixDB. The purpose of this demo is to illustrate how a "cool application" can be built using the JavaScript SDK of AsterixDB and to exercise all of the AsterixDB HTTP APIs. If you are building an app of your own, reading the code for this app is a great way to get acquainted with what you'll need to know.</p>
+ <p>Welcome to the top-level page of the Tweetbook Demo of AsterixDB. The purpose of this demo is to illustrate how a "cool application" can be built using the JavaScript SDK of AsterixDB and to exercise all of the AsterixDB HTTP APIs. If you are building an app of your own, reading the code for this app is a great way to get acquainted with what you'll need to know.</p>
- <p>In this demo, which is based on spatial analysis of Tweets (it is 2013, afterall), you will see how to formulate aggregate queries and drill-down queries using the query door of the AsterixDB API. You will see how to do this either synchronously or asynchronously (for larger queries whose results may take a while to cook). You will also see how to create and drop datasets (to manage Tweetbooks, notebooks with user commentary on Tweets) and how to perform inserts and deletes (to add/remove Tweetbook entries). Let's walk through the demo.</p>
+ <p>In this demo, which is based on spatial analysis of Tweets, you will see how to formulate aggregate queries and drill-down queries using the query door of the AsterixDB API. You will see how to do this either synchronously or asynchronously (for larger queries whose results may take a while to cook). You will also see how to create and drop datasets (to manage Tweetbooks, notebooks with user commentary on Tweets) and how to perform inserts and deletes (to add/remove Tweetbook entries). Let's walk through the demo.</p>
</div>
<hr/>
diff --git a/asterix-examples/src/main/resources/black-cherry/black_cherry_bootstrap.py b/asterix-examples/src/main/resources/tweetbook-demo/tweetbook_bootstrap.py
similarity index 96%
rename from asterix-examples/src/main/resources/black-cherry/black_cherry_bootstrap.py
rename to asterix-examples/src/main/resources/tweetbook-demo/tweetbook_bootstrap.py
index 0852fe2..d27939a 100755
--- a/asterix-examples/src/main/resources/black-cherry/black_cherry_bootstrap.py
+++ b/asterix-examples/src/main/resources/tweetbook-demo/tweetbook_bootstrap.py
@@ -11,7 +11,7 @@
# First, let's get the path to this script, we'll need it to configure the demo.
base = os.path.dirname(os.path.realpath(__file__))
- print "Running Black Cherry from",base
+ print "Running Tweetbook Demo from",base
# First, we bootstrap our request query
print "Preparing Dataset..."
diff --git a/asterix-examples/src/main/resources/black-cherry/static/data/query.txt b/asterix-examples/src/main/resources/tweetbook-demo/static/data/query.txt
similarity index 100%
rename from asterix-examples/src/main/resources/black-cherry/static/data/query.txt
rename to asterix-examples/src/main/resources/tweetbook-demo/static/data/query.txt
diff --git a/asterix-examples/src/main/resources/black-cherry/static/data/twm.adm b/asterix-examples/src/main/resources/tweetbook-demo/static/data/twm.adm
similarity index 100%
rename from asterix-examples/src/main/resources/black-cherry/static/data/twm.adm
rename to asterix-examples/src/main/resources/tweetbook-demo/static/data/twm.adm
Binary files differ
diff --git a/asterix-examples/src/main/resources/black-cherry/static/img/Tutorial1.png b/asterix-examples/src/main/resources/tweetbook-demo/static/img/Tutorial1.png
similarity index 100%
rename from asterix-examples/src/main/resources/black-cherry/static/img/Tutorial1.png
rename to asterix-examples/src/main/resources/tweetbook-demo/static/img/Tutorial1.png
Binary files differ
diff --git a/asterix-examples/src/main/resources/black-cherry/static/img/Tutorial2.png b/asterix-examples/src/main/resources/tweetbook-demo/static/img/Tutorial2.png
similarity index 100%
rename from asterix-examples/src/main/resources/black-cherry/static/img/Tutorial2.png
rename to asterix-examples/src/main/resources/tweetbook-demo/static/img/Tutorial2.png
Binary files differ
diff --git a/asterix-examples/src/main/resources/black-cherry/static/img/Tutorial3.png b/asterix-examples/src/main/resources/tweetbook-demo/static/img/Tutorial3.png
similarity index 100%
rename from asterix-examples/src/main/resources/black-cherry/static/img/Tutorial3.png
rename to asterix-examples/src/main/resources/tweetbook-demo/static/img/Tutorial3.png
Binary files differ
diff --git a/asterix-examples/src/main/resources/black-cherry/static/img/Tutorial4.png b/asterix-examples/src/main/resources/tweetbook-demo/static/img/Tutorial4.png
similarity index 100%
rename from asterix-examples/src/main/resources/black-cherry/static/img/Tutorial4.png
rename to asterix-examples/src/main/resources/tweetbook-demo/static/img/Tutorial4.png
Binary files differ
diff --git a/asterix-examples/src/main/resources/black-cherry/static/img/finalasterixlogo.png b/asterix-examples/src/main/resources/tweetbook-demo/static/img/finalasterixlogo.png
similarity index 100%
rename from asterix-examples/src/main/resources/black-cherry/static/img/finalasterixlogo.png
rename to asterix-examples/src/main/resources/tweetbook-demo/static/img/finalasterixlogo.png
Binary files differ
diff --git a/asterix-examples/src/main/resources/black-cherry/static/img/glyphicons-halflings-white.png b/asterix-examples/src/main/resources/tweetbook-demo/static/img/glyphicons-halflings-white.png
similarity index 100%
rename from asterix-examples/src/main/resources/black-cherry/static/img/glyphicons-halflings-white.png
rename to asterix-examples/src/main/resources/tweetbook-demo/static/img/glyphicons-halflings-white.png
Binary files differ
diff --git a/asterix-examples/src/main/resources/black-cherry/static/img/glyphicons-halflings.png b/asterix-examples/src/main/resources/tweetbook-demo/static/img/glyphicons-halflings.png
similarity index 100%
rename from asterix-examples/src/main/resources/black-cherry/static/img/glyphicons-halflings.png
rename to asterix-examples/src/main/resources/tweetbook-demo/static/img/glyphicons-halflings.png
Binary files differ
diff --git a/asterix-examples/src/main/resources/black-cherry/static/img/hyrax.png b/asterix-examples/src/main/resources/tweetbook-demo/static/img/hyrax.png
similarity index 100%
rename from asterix-examples/src/main/resources/black-cherry/static/img/hyrax.png
rename to asterix-examples/src/main/resources/tweetbook-demo/static/img/hyrax.png
Binary files differ
diff --git a/asterix-examples/src/main/resources/black-cherry/static/img/markers.png b/asterix-examples/src/main/resources/tweetbook-demo/static/img/markers.png
similarity index 100%
rename from asterix-examples/src/main/resources/black-cherry/static/img/markers.png
rename to asterix-examples/src/main/resources/tweetbook-demo/static/img/markers.png
Binary files differ
diff --git a/asterix-examples/src/main/resources/black-cherry/static/img/mobile2.png b/asterix-examples/src/main/resources/tweetbook-demo/static/img/mobile2.png
similarity index 100%
rename from asterix-examples/src/main/resources/black-cherry/static/img/mobile2.png
rename to asterix-examples/src/main/resources/tweetbook-demo/static/img/mobile2.png
Binary files differ
diff --git a/asterix-examples/src/main/resources/black-cherry/static/img/mobile_green2.png b/asterix-examples/src/main/resources/tweetbook-demo/static/img/mobile_green2.png
similarity index 100%
rename from asterix-examples/src/main/resources/black-cherry/static/img/mobile_green2.png
rename to asterix-examples/src/main/resources/tweetbook-demo/static/img/mobile_green2.png
Binary files differ
diff --git a/asterix-examples/src/main/resources/black-cherry/static/js/asterix-sdk-stable.js b/asterix-examples/src/main/resources/tweetbook-demo/static/js/asterix-sdk-stable.js
similarity index 100%
rename from asterix-examples/src/main/resources/black-cherry/static/js/asterix-sdk-stable.js
rename to asterix-examples/src/main/resources/tweetbook-demo/static/js/asterix-sdk-stable.js
diff --git a/asterix-examples/src/main/resources/black-cherry/static/js/bootstrap.min.js b/asterix-examples/src/main/resources/tweetbook-demo/static/js/bootstrap.min.js
similarity index 100%
rename from asterix-examples/src/main/resources/black-cherry/static/js/bootstrap.min.js
rename to asterix-examples/src/main/resources/tweetbook-demo/static/js/bootstrap.min.js
diff --git a/asterix-examples/src/main/resources/black-cherry/static/js/geostats.js b/asterix-examples/src/main/resources/tweetbook-demo/static/js/geostats.js
similarity index 100%
rename from asterix-examples/src/main/resources/black-cherry/static/js/geostats.js
rename to asterix-examples/src/main/resources/tweetbook-demo/static/js/geostats.js
diff --git a/asterix-examples/src/main/resources/black-cherry/static/js/rainbowvis.js b/asterix-examples/src/main/resources/tweetbook-demo/static/js/rainbowvis.js
similarity index 100%
rename from asterix-examples/src/main/resources/black-cherry/static/js/rainbowvis.js
rename to asterix-examples/src/main/resources/tweetbook-demo/static/js/rainbowvis.js
diff --git a/asterix-examples/src/main/resources/black-cherry/static/js/cherry.js b/asterix-examples/src/main/resources/tweetbook-demo/static/js/tweetbook.js
similarity index 97%
rename from asterix-examples/src/main/resources/black-cherry/static/js/cherry.js
rename to asterix-examples/src/main/resources/tweetbook-demo/static/js/tweetbook.js
index e32f01c..61ecedb 100755
--- a/asterix-examples/src/main/resources/black-cherry/static/js/cherry.js
+++ b/asterix-examples/src/main/resources/tweetbook-demo/static/js/tweetbook.js
@@ -234,9 +234,9 @@
formData["neLat"] = Math.max(swLat, neLat);
formData["neLng"] = Math.min(swLng, neLng);
- var build_cherry_mode = "synchronous";
+ var build_tweetbook_mode = "synchronous";
if ($('#asbox').is(":checked")) {
- build_cherry_mode = "asynchronous";
+ build_tweetbook_mode = "asynchronous";
}
var f = buildAQLQueryFromForm(formData);
@@ -246,10 +246,10 @@
"data" : formData
};
- if (build_cherry_mode == "synchronous") {
- A.query(f.val(), cherryQuerySyncCallback, build_cherry_mode);
+ if (build_tweetbook_mode == "synchronous") {
+ A.query(f.val(), tweetbookQuerySyncCallback, build_tweetbook_mode);
} else {
- A.query(f.val(), cherryQueryAsyncCallback, build_cherry_mode);
+ A.query(f.val(), tweetbookQueryAsyncCallback, build_tweetbook_mode);
}
// Clears selection rectangle on query execution, rather than waiting for another clear call.
@@ -408,7 +408,7 @@
* On-success callback after async API query
* @param {object} res, a result object containing an opaque result handle to Asterix
*/
-function cherryQueryAsyncCallback(res) {
+function tweetbookQueryAsyncCallback(res) {
// Parse handle, handle id and query from async call result
var handle_query = APIqueryTracker["query"];
@@ -458,7 +458,7 @@
"results" : res.results
};
- cherryQuerySyncCallback(resultTransform);
+ tweetbookQuerySyncCallback(resultTransform);
}
);
} else {
@@ -467,7 +467,7 @@
"results" : asyncQueryManager[handle_id]["result"].results
};
- cherryQuerySyncCallback(resultTransform);
+ tweetbookQuerySyncCallback(resultTransform);
}
}
});
@@ -489,9 +489,9 @@
/**
* A spatial data cleaning and mapping call
* @param {Object} res, a result object from a cherry geospatial query
*/
-function cherryQuerySyncCallback(res) {
+function tweetbookQuerySyncCallback(res) {
// First, we check if any results came back in.
// If they didn't, return.
if (!res.hasOwnProperty("results")) {
@@ -489,9 +489,9 @@
/**
* A spatial data cleaning and mapping call
-* @param {Object} res, a result object from a cherry geospatial query
+* @param {Object} res, a result object from a tweetbook geospatial query
*/